@@ -7,9 +7,21 @@ sub build
 	my $r = $self->routes;
 
 	$r->add('/home', 'home');
+}
+
+sub build_from_methods
+{
+	my $self = shift;
 	$self->symbiosis->mount('/test', $self->testmod);
-	$self->symbiosis->mount('/test2', $self->another);
-	$self->symbiosis->mount('/test/test', $self->another);
+}
+
+sub build_from_loaded
+{
+	my $self = shift;
+
+	$self->symbiosis->mount('/s', $self);
+	$self->symbiosis->mount('/test', 'symbiont');
+	$self->symbiosis->mount('/test/test2', 'AnotherTestSymbiont');
 }
 
 sub home
