@@ -6,7 +6,7 @@ use Plack::Response;
 # Some module that can be served by Plack via run()
 # extending Symbiosis::Base
 
-attr -num => 1;
+sub name { 'symbiont' }
 
 sub psgi
 {
@@ -14,7 +14,7 @@ sub psgi
 
 	return sub {
 		my $res = Plack::Response->new(200);
-		$res->body("mounted" . $self->num);
+		$res->body("mounted");
 		return $res->finalize;
 	};
 }
@@ -24,20 +24,7 @@ sub build
 	my ($self, %args) = @_;
 	$self->SUPER::build(%args);
 
-	$self->register(
-		testmod => sub {
-			return $self;
-		}
-	);
-
-	my $max_num = $self->num;
-	$self->register(
-		another => sub {
-			my $another = __PACKAGE__->new(app => $self->app, num => ++$max_num);
-			$another->SUPER::build(%args);
-			return $another;
-		}
-	);
+	$self->register(testmod => $self);
 }
 
 1;
